info = {
    "name": "xog",
    "date_order": "DMY",
    "january": [
        "jan",
        "janwaliyo"
    ],
    "february": [
        "feb",
        "febwaliyo"
    ],
    "march": [
        "mar",
        "marisi"
    ],
    "april": [
        "apu",
        "apuli"
    ],
    "may": [
        "maa",
        "maayi"
    ],
    "june": [
        "juu",
        "juuni"
    ],
    "july": [
        "jul",
        "julaayi"
    ],
    "august": [
        "agu",
        "agusito"
    ],
    "september": [
        "seb",
        "sebuttemba"
    ],
    "october": [
        "oki",
        "okitobba"
    ],
    "november": [
        "nov",
        "novemba"
    ],
    "december": [
        "des",
        "desemba"
    ],
    "monday": [
        "bala",
        "balaza"
    ],
    "tuesday": [
        "kubi",
        "owokubili"
    ],
    "wednesday": [
        "kusa",
        "owokusatu"
    ],
    "thursday": [
        "kuna",
        "olokuna"
    ],
    "friday": [
        "kuta",
        "olokutaanu"
    ],
    "saturday": [
        "muka",
        "olomukaaga"
    ],
    "sunday": [
        "sabi",
        "sabiiti"
    ],
    "am": [
        "munkyo"
    ],
    "pm": [
        "eigulo"
    ],
    "year": [
        "omwaka"
    ],
    "month": [
        "omwezi"
    ],
    "week": [
        "esabiiti"
    ],
    "day": [
        "olunaku"
    ],
    "hour": [
        "essawa"
    ],
    "minute": [
        "edakiika"
    ],
    "second": [
        "obutikitiki"
    ],
    "relative-type": {
        "0 day ago": [
            "olwaleelo (leelo)"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "edho"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "enkyo"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
