info = {
    "name": "os",
    "date_order": "DMY",
    "january": [
        "янв",
        "январы",
        "январь"
    ],
    "february": [
        "фев",
        "февр",
        "февралы",
        "февраль"
    ],
    "march": [
        "мар",
        "март",
        "мартъи",
        "мартъийы"
    ],
    "april": [
        "апр",
        "апрелы",
        "апрель"
    ],
    "may": [
        "май",
        "майы"
    ],
    "june": [
        "июны",
        "июнь"
    ],
    "july": [
        "июлы",
        "июль"
    ],
    "august": [
        "авг",
        "август",
        "августы"
    ],
    "september": [
        "сен",
        "сент",
        "сентябры",
        "сентябрь"
    ],
    "october": [
        "окт",
        "октябры",
        "октябрь"
    ],
    "november": [
        "ноя",
        "нояб",
        "ноябры",
        "ноябрь"
    ],
    "december": [
        "дек",
        "декабры",
        "декабрь"
    ],
    "monday": [
        "крс",
        "къуырисӕр"
    ],
    "tuesday": [
        "дцг",
        "дыццӕг"
    ],
    "wednesday": [
        "ӕрт",
        "ӕртыццӕг"
    ],
    "thursday": [
        "цпр",
        "цыппӕрӕм"
    ],
    "friday": [
        "майрӕмбон",
        "мрб"
    ],
    "saturday": [
        "сабат",
        "сбт"
    ],
    "sunday": [
        "хуыцаубон",
        "хцб"
    ],
    "am": [
        "am",
        "ӕмбисбоны размӕ"
    ],
    "pm": [
        "pm",
        "ӕмбисбоны фӕстӕ"
    ],
    "year": [
        "аз"
    ],
    "month": [
        "мӕй"
    ],
    "week": [
        "къуыри"
    ],
    "day": [
        "бон"
    ],
    "hour": [
        "сахат"
    ],
    "minute": [
        "минут"
    ],
    "second": [
        "секунд"
    ],
    "relative-type": {
        "0 day ago": [
            "абон"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "знон"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "сом"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "(\\d+[.,]?\\d*) бон раздӕр",
            "(\\d+[.,]?\\d*) боны размӕ"
        ],
        "\\1 hour ago": [
            "(\\d+[.,]?\\d*) сахаты размӕ"
        ],
        "in \\1 day": [
            "(\\d+[.,]?\\d*) боны фӕстӕ"
        ],
        "in \\1 hour": [
            "(\\d+[.,]?\\d*) сахаты фӕстӕ"
        ]
    },
    "locale_specific": {
        "os-RU": {
            "name": "os-RU"
        }
    },
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
