info = {
    "name": "seh",
    "date_order": "DMY",
    "january": [
        "jan",
        "janeiro"
    ],
    "february": [
        "fev",
        "fevreiro"
    ],
    "march": [
        "mar",
        "marco"
    ],
    "april": [
        "abr",
        "abril"
    ],
    "may": [
        "mai",
        "maio"
    ],
    "june": [
        "jun",
        "junho"
    ],
    "july": [
        "jul",
        "julho"
    ],
    "august": [
        "aug",
        "augusto"
    ],
    "september": [
        "set",
        "setembro"
    ],
    "october": [
        "otu",
        "otubro"
    ],
    "november": [
        "nov",
        "novembro"
    ],
    "december": [
        "dec",
        "decembro"
    ],
    "monday": [
        "chiposi",
        "pos"
    ],
    "tuesday": [
        "chipiri",
        "pir"
    ],
    "wednesday": [
        "chitatu",
        "tat"
    ],
    "thursday": [
        "chinai",
        "nai"
    ],
    "friday": [
        "chishanu",
        "sha"
    ],
    "saturday": [
        "sab",
        "sabudu"
    ],
    "sunday": [
        "dim",
        "dimingu"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "chaka"
    ],
    "month": [
        "mwezi"
    ],
    "week": [
        "week"
    ],
    "day": [
        "ntsiku"
    ],
    "hour": [
        "hora"
    ],
    "minute": [
        "minuto"
    ],
    "second": [
        "segundo"
    ],
    "relative-type": {
        "0 day ago": [
            "lero"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "zuro"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "manguana"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
