info = {
    "name": "kam",
    "date_order": "DMY",
    "january": [
        "mbe",
        "mwai wa mbee"
    ],
    "february": [
        "kel",
        "mwai wa kelĩ"
    ],
    "march": [
        "ktũ",
        "mwai wa katatũ"
    ],
    "april": [
        "kan",
        "mwai wa kana"
    ],
    "may": [
        "ktn",
        "mwai wa katano"
    ],
    "june": [
        "mwai wa thanthatũ",
        "tha"
    ],
    "july": [
        "moo",
        "mwai wa muonza"
    ],
    "august": [
        "mwai wa nyaanya",
        "nya"
    ],
    "september": [
        "knd",
        "mwai wa kenda"
    ],
    "october": [
        "mwai wa ĩkumi",
        "ĩku"
    ],
    "november": [
        "mwai wa ĩkumi na ĩmwe",
        "ĩkm"
    ],
    "december": [
        "mwai wa ĩkumi na ilĩ",
        "ĩkl"
    ],
    "monday": [
        "wa kwambĩlĩlya",
        "wkw"
    ],
    "tuesday": [
        "wa kelĩ",
        "wkl"
    ],
    "wednesday": [
        "wa katatũ",
        "wtũ"
    ],
    "thursday": [
        "wa kana",
        "wkn"
    ],
    "friday": [
        "wa katano",
        "wtn"
    ],
    "saturday": [
        "wa thanthatũ",
        "wth"
    ],
    "sunday": [
        "wa kyumwa",
        "wky"
    ],
    "am": [
        "ĩyakwakya"
    ],
    "pm": [
        "ĩyawĩoo"
    ],
    "year": [
        "mwaka"
    ],
    "month": [
        "mwai"
    ],
    "week": [
        "kyumwa"
    ],
    "day": [
        "mũthenya"
    ],
    "hour": [
        "saa"
    ],
    "minute": [
        "ndatĩka"
    ],
    "second": [
        "sekondi"
    ],
    "relative-type": {
        "0 day ago": [
            "ũmũnthĩ"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "ĩyoo"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "ũnĩ"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
