info = {
    "name": "bez",
    "date_order": "DMY",
    "january": [
        "hut",
        "pa mwedzi gwa hutala"
    ],
    "february": [
        "pa mwedzi gwa wuvili",
        "vil"
    ],
    "march": [
        "dat",
        "pa mwedzi gwa wudatu"
    ],
    "april": [
        "pa mwedzi gwa wutai",
        "tai"
    ],
    "may": [
        "han",
        "pa mwedzi gwa wuhanu"
    ],
    "june": [
        "pa mwedzi gwa sita",
        "sit"
    ],
    "july": [
        "pa mwedzi gwa saba",
        "sab"
    ],
    "august": [
        "nan",
        "pa mwedzi gwa nane"
    ],
    "september": [
        "pa mwedzi gwa tisa",
        "tis"
    ],
    "october": [
        "kum",
        "pa mwedzi gwa kumi"
    ],
    "november": [
        "kmj",
        "pa mwedzi gwa kumi na moja"
    ],
    "december": [
        "kmb",
        "pa mwedzi gwa kumi na mbili"
    ],
    "monday": [
        "pa shahuviluha",
        "vil"
    ],
    "tuesday": [
        "hiv",
        "pa hivili"
    ],
    "wednesday": [
        "hid",
        "pa hidatu"
    ],
    "thursday": [
        "hit",
        "pa hitayi"
    ],
    "friday": [
        "hih",
        "pa hihanu"
    ],
    "saturday": [
        "lem",
        "pa shahulembela"
    ],
    "sunday": [
        "mul",
        "pa mulungu"
    ],
    "am": [
        "pamilau"
    ],
    "pm": [
        "pamunyi"
    ],
    "year": [
        "mwaha"
    ],
    "month": [
        "mwedzi"
    ],
    "week": [
        "mlungu gumamfu"
    ],
    "day": [
        "sihu"
    ],
    "hour": [
        "saa"
    ],
    "minute": [
        "dakika"
    ],
    "second": [
        "sekunde"
    ],
    "relative-type": {
        "0 day ago": [
            "neng'u ni"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "igolo"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "hilawu"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
