info = {
    "name": "uz-Cyrl",
    "date_order": "DMY",
    "january": [
        "янв",
        "январ"
    ],
    "february": [
        "фев",
        "феврал"
    ],
    "march": [
        "мар",
        "март"
    ],
    "april": [
        "апр",
        "апрел"
    ],
    "may": [
        "май"
    ],
    "june": [
        "июн"
    ],
    "july": [
        "июл"
    ],
    "august": [
        "авг",
        "август"
    ],
    "september": [
        "сен",
        "сентябр"
    ],
    "october": [
        "окт",
        "октябр"
    ],
    "november": [
        "ноя",
        "ноябр"
    ],
    "december": [
        "дек",
        "декабр"
    ],
    "monday": [
        "душ",
        "душанба"
    ],
    "tuesday": [
        "сеш",
        "сешанба"
    ],
    "wednesday": [
        "чор",
        "чоршанба"
    ],
    "thursday": [
        "пай",
        "пайшанба"
    ],
    "friday": [
        "жум",
        "жума"
    ],
    "saturday": [
        "шан",
        "шанба"
    ],
    "sunday": [
        "якш",
        "якшанба"
    ],
    "am": [
        "то"
    ],
    "pm": [
        "тк"
    ],
    "year": [
        "йил"
    ],
    "month": [
        "ой"
    ],
    "week": [
        "ҳафта"
    ],
    "day": [
        "кун"
    ],
    "hour": [
        "соат"
    ],
    "minute": [
        "дақиқа"
    ],
    "second": [
        "сония"
    ],
    "relative-type": {
        "0 day ago": [
            "бугун"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "бу ой"
        ],
        "0 second ago": [
            "ҳозир"
        ],
        "0 week ago": [
            "бу ҳафта"
        ],
        "0 year ago": [
            "бу йил"
        ],
        "1 day ago": [
            "кеча"
        ],
        "1 month ago": [
            "ўтган ой"
        ],
        "1 week ago": [
            "ўтган ҳафта"
        ],
        "1 year ago": [
            "ўтган йил"
        ],
        "in 1 day": [
            "эртага"
        ],
        "in 1 month": [
            "кейинги ой"
        ],
        "in 1 week": [
            "кейинги ҳафта"
        ],
        "in 1 year": [
            "кейинги йил"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "(\\d+[.,]?\\d*) кун олдин"
        ],
        "\\1 hour ago": [
            "(\\d+[.,]?\\d*) соат олдин"
        ],
        "\\1 minute ago": [
            "(\\d+[.,]?\\d*) дақиқа олдин"
        ],
        "\\1 month ago": [
            "(\\d+[.,]?\\d*) ой аввал"
        ],
        "\\1 second ago": [
            "(\\d+[.,]?\\d*) сония олдин"
        ],
        "\\1 week ago": [
            "(\\d+[.,]?\\d*) ҳафта олдин"
        ],
        "\\1 year ago": [
            "(\\d+[.,]?\\d*) йил аввал"
        ],
        "in \\1 day": [
            "(\\d+[.,]?\\d*) кундан сўнг"
        ],
        "in \\1 hour": [
            "(\\d+[.,]?\\d*) соатдан сўнг"
        ],
        "in \\1 minute": [
            "(\\d+[.,]?\\d*) дақиқадан сўнг"
        ],
        "in \\1 month": [
            "(\\d+[.,]?\\d*) ойдан сўнг"
        ],
        "in \\1 second": [
            "(\\d+[.,]?\\d*) сониядан сўнг"
        ],
        "in \\1 week": [
            "(\\d+[.,]?\\d*) ҳафтадан сўнг"
        ],
        "in \\1 year": [
            "(\\d+[.,]?\\d*) йилдан сўнг"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
