info = {
    "name": "bas",
    "date_order": "DMY",
    "january": [
        "kɔn",
        "kɔndɔŋ"
    ],
    "february": [
        "mac",
        "màcɛ̂l"
    ],
    "march": [
        "mat",
        "màtùmb"
    ],
    "april": [
        "mto",
        "màtop"
    ],
    "may": [
        "mpu",
        "m̀puyɛ"
    ],
    "june": [
        "hil",
        "hìlòndɛ̀"
    ],
    "july": [
        "nje",
        "njèbà"
    ],
    "august": [
        "hik",
        "hìkaŋ"
    ],
    "september": [
        "dip",
        "dìpɔ̀s"
    ],
    "october": [
        "bio",
        "bìòôm"
    ],
    "november": [
        "may",
        "màyɛsèp"
    ],
    "december": [
        "liɓ",
        "lìbuy li ńyèe"
    ],
    "monday": [
        "nja",
        "ŋgwà njaŋgumba"
    ],
    "tuesday": [
        "uum",
        "ŋgwà ûm"
    ],
    "wednesday": [
        "ŋge",
        "ŋgwà ŋgê"
    ],
    "thursday": [
        "mbɔ",
        "ŋgwà mbɔk"
    ],
    "friday": [
        "kɔɔ",
        "ŋgwà kɔɔ"
    ],
    "saturday": [
        "jon",
        "ŋgwà jôn"
    ],
    "sunday": [
        "nɔy",
        "ŋgwà nɔ̂y"
    ],
    "am": [
        "i bikɛ̂glà"
    ],
    "pm": [
        "i ɓugajɔp"
    ],
    "year": [
        "ŋwìi"
    ],
    "month": [
        "soŋ"
    ],
    "week": [
        "sɔndɛ̂"
    ],
    "day": [
        "kɛl"
    ],
    "hour": [
        "ŋgɛŋ"
    ],
    "minute": [
        "ŋget"
    ],
    "second": [
        "hìŋgeŋget"
    ],
    "relative-type": {
        "0 day ago": [
            "lɛ̀n"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "yààni"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "yàni"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
