info = {
    "name": "so",
    "date_order": "DMY",
    "january": [
        "bisha koobaad",
        "kob"
    ],
    "february": [
        "bisha labaad",
        "lab"
    ],
    "march": [
        "bisha saddexaad",
        "sad"
    ],
    "april": [
        "afr",
        "bisha afraad"
    ],
    "may": [
        "bisha shanaad",
        "sha"
    ],
    "june": [
        "bisha lixaad",
        "lix"
    ],
    "july": [
        "bisha todobaad",
        "tod"
    ],
    "august": [
        "bisha sideedaad",
        "sid"
    ],
    "september": [
        "bisha sagaalaad",
        "sag"
    ],
    "october": [
        "bisha tobnaad",
        "tob"
    ],
    "november": [
        "bisha kow iyo tobnaad",
        "kit"
    ],
    "december": [
        "bisha laba iyo tobnaad",
        "lit"
    ],
    "monday": [
        "isn",
        "isniin"
    ],
    "tuesday": [
        "tal",
        "talaado"
    ],
    "wednesday": [
        "arb",
        "arbaco"
    ],
    "thursday": [
        "kha",
        "khamiis"
    ],
    "friday": [
        "jim",
        "jimco"
    ],
    "saturday": [
        "sab",
        "sabti"
    ],
    "sunday": [
        "axad",
        "axd"
    ],
    "am": [
        "sn"
    ],
    "pm": [
        "gn"
    ],
    "year": [
        "year"
    ],
    "month": [
        "month"
    ],
    "week": [
        "week"
    ],
    "day": [
        "day"
    ],
    "hour": [
        "hour"
    ],
    "minute": [
        "minute"
    ],
    "second": [
        "second"
    ],
    "relative-type": {
        "0 day ago": [
            "maanta"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "shalay"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "berri"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {
        "so-DJ": {
            "name": "so-DJ"
        },
        "so-ET": {
            "name": "so-ET"
        },
        "so-KE": {
            "name": "so-KE"
        }
    },
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
