info = {
    "name": "lkt",
    "date_order": "YMD",
    "january": [
        "wiótheȟika wí"
    ],
    "february": [
        "thiyóȟeyuŋka wí"
    ],
    "march": [
        "ištáwičhayazaŋ wí"
    ],
    "april": [
        "pȟežítȟo wí"
    ],
    "may": [
        "čhaŋwápetȟo wí"
    ],
    "june": [
        "wípazukȟa-wašté wí"
    ],
    "july": [
        "čhaŋpȟásapa wí"
    ],
    "august": [
        "wasútȟuŋ wí"
    ],
    "september": [
        "čhaŋwápeǧi wí"
    ],
    "october": [
        "čhaŋwápe-kasná wí"
    ],
    "november": [
        "waníyetu wí"
    ],
    "december": [
        "tȟahékapšuŋ wí"
    ],
    "monday": [
        "aŋpétuwaŋži"
    ],
    "tuesday": [
        "aŋpétunuŋpa"
    ],
    "wednesday": [
        "aŋpétuyamni"
    ],
    "thursday": [
        "aŋpétutopa"
    ],
    "friday": [
        "aŋpétuzaptaŋ"
    ],
    "saturday": [
        "owáŋgyužažapi"
    ],
    "sunday": [
        "aŋpétuwakȟaŋ"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "ómakȟa"
    ],
    "month": [
        "wí"
    ],
    "week": [
        "okó"
    ],
    "day": [
        "aŋpétu"
    ],
    "hour": [
        "owápȟe"
    ],
    "minute": [
        "owápȟe oȟ'áŋkȟo"
    ],
    "second": [
        "okpí"
    ],
    "relative-type": {
        "0 day ago": [
            "lé aŋpétu kiŋ"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "lé wí kiŋ"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "lé okó kiŋ"
        ],
        "0 year ago": [
            "lé ómakȟa kiŋ"
        ],
        "1 day ago": [
            "ȟtálehaŋ"
        ],
        "1 month ago": [
            "wí k'uŋ héhaŋ"
        ],
        "1 week ago": [
            "okó k'uŋ héhaŋ"
        ],
        "1 year ago": [
            "ómakȟa k'uŋ héhaŋ"
        ],
        "in 1 day": [
            "híŋhaŋni kiŋháŋ"
        ],
        "in 1 month": [
            "tȟokáta wí kiŋháŋ"
        ],
        "in 1 week": [
            "tȟokáta okó kiŋháŋ"
        ],
        "in 1 year": [
            "tȟokáta ómakȟa kiŋháŋ"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "hékta (\\d+[.,]?\\d*)-čháŋ k'uŋ héhaŋ"
        ],
        "\\1 hour ago": [
            "hékta owápȟe (\\d+[.,]?\\d*) k'uŋ héhaŋ"
        ],
        "\\1 minute ago": [
            "hékta oȟ'áŋkȟo (\\d+[.,]?\\d*) k'uŋ héhaŋ"
        ],
        "\\1 month ago": [
            "hékta wíyawapi (\\d+[.,]?\\d*) k'uŋ héhaŋ"
        ],
        "\\1 second ago": [
            "hékta okpí (\\d+[.,]?\\d*) k'uŋ héhaŋ"
        ],
        "\\1 week ago": [
            "hékta okó (\\d+[.,]?\\d*) k'uŋ héhaŋ"
        ],
        "\\1 year ago": [
            "hékta ómakȟa (\\d+[.,]?\\d*) k'uŋ héhaŋ"
        ],
        "in \\1 day": [
            "letáŋhaŋ (\\d+[.,]?\\d*)-čháŋ kiŋháŋ"
        ],
        "in \\1 hour": [
            "letáŋhaŋ owápȟe (\\d+[.,]?\\d*) kiŋháŋ"
        ],
        "in \\1 minute": [
            "letáŋhaŋ oȟ'áŋkȟo (\\d+[.,]?\\d*) kiŋháŋ"
        ],
        "in \\1 month": [
            "letáŋhaŋ wíyawapi (\\d+[.,]?\\d*) kiŋháŋ"
        ],
        "in \\1 second": [
            "letáŋhaŋ okpí (\\d+[.,]?\\d*) kiŋháŋ"
        ],
        "in \\1 week": [
            "letáŋhaŋ okó (\\d+[.,]?\\d*) kiŋháŋ"
        ],
        "in \\1 year": [
            "letáŋhaŋ ómakȟa (\\d+[.,]?\\d*) kiŋháŋ"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
