info = {
    "name": "luo",
    "date_order": "DMY",
    "january": [
        "dac",
        "dwe mar achiel"
    ],
    "february": [
        "dar",
        "dwe mar ariyo"
    ],
    "march": [
        "dad",
        "dwe mar adek"
    ],
    "april": [
        "dan",
        "dwe mar ang'wen"
    ],
    "may": [
        "dah",
        "dwe mar abich"
    ],
    "june": [
        "dau",
        "dwe mar auchiel"
    ],
    "july": [
        "dao",
        "dwe mar abiriyo"
    ],
    "august": [
        "dab",
        "dwe mar aboro"
    ],
    "september": [
        "doc",
        "dwe mar ochiko"
    ],
    "october": [
        "dap",
        "dwe mar apar"
    ],
    "november": [
        "dgi",
        "dwe mar gi achiel"
    ],
    "december": [
        "dag",
        "dwe mar apar gi ariyo"
    ],
    "monday": [
        "wuok tich",
        "wut"
    ],
    "tuesday": [
        "tar",
        "tich ariyo"
    ],
    "wednesday": [
        "tad",
        "tich adek"
    ],
    "thursday": [
        "tan",
        "tich ang'wen"
    ],
    "friday": [
        "tab",
        "tich abich"
    ],
    "saturday": [
        "ngeso",
        "ngs"
    ],
    "sunday": [
        "jmp",
        "jumapil"
    ],
    "am": [
        "od"
    ],
    "pm": [
        "ot"
    ],
    "year": [
        "higa"
    ],
    "month": [
        "dwe"
    ],
    "week": [
        "juma"
    ],
    "day": [
        "chieng'"
    ],
    "hour": [
        "saa"
    ],
    "minute": [
        "dakika"
    ],
    "second": [
        "nyiriri mar saa"
    ],
    "relative-type": {
        "0 day ago": [
            "kawuono"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "nyoro"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "kiny"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
