info = {
    "name": "ebu",
    "date_order": "DMY",
    "january": [
        "mbe",
        "mweri wa mbere"
    ],
    "february": [
        "kai",
        "mweri wa kaĩri"
    ],
    "march": [
        "kat",
        "mweri wa kathatũ"
    ],
    "april": [
        "kan",
        "mweri wa kana"
    ],
    "may": [
        "gat",
        "mweri wa gatano"
    ],
    "june": [
        "gan",
        "mweri wa gatantatũ"
    ],
    "july": [
        "mug",
        "mweri wa mũgwanja"
    ],
    "august": [
        "knn",
        "mweri wa kanana"
    ],
    "september": [
        "ken",
        "mweri wa kenda"
    ],
    "october": [
        "iku",
        "mweri wa ikũmi"
    ],
    "november": [
        "imw",
        "mweri wa ikũmi na ũmwe"
    ],
    "december": [
        "igi",
        "mweri wa ikũmi na kaĩrĩ"
    ],
    "monday": [
        "njumatatu",
        "tat"
    ],
    "tuesday": [
        "ine",
        "njumaine"
    ],
    "wednesday": [
        "njumatano",
        "tan"
    ],
    "thursday": [
        "aramithi",
        "arm"
    ],
    "friday": [
        "maa",
        "njumaa"
    ],
    "saturday": [
        "njumamothii",
        "nmm"
    ],
    "sunday": [
        "kiumia",
        "kma"
    ],
    "am": [
        "ki"
    ],
    "pm": [
        "ut"
    ],
    "year": [
        "mwaka"
    ],
    "month": [
        "mweri"
    ],
    "week": [
        "kiumia"
    ],
    "day": [
        "mũthenya"
    ],
    "hour": [
        "ithaa"
    ],
    "minute": [
        "ndagĩka"
    ],
    "second": [
        "sekondi"
    ],
    "relative-type": {
        "0 day ago": [
            "ũmũnthĩ"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "ĩgoro"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "rũciũ"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
